pub struct SelfClosingTagConfig {
pub before: Insertion,
pub after: Insertion,
}Expand description
Defines the configuration of a self-closing tag element, e.g. in HTML <img>.
This struct stores the insertion before and the insertion after a tag identifier. Have a look at
the documentation of Insertion too.
Fields
before: InsertionOptional character to be set before a single tag name (opening character).
after: InsertionOptional character to be set after a single tag (closing character).