pub struct NoFormatting;Expand description
A pre-implemented formatter for having no formatting at all. No linefeeds, no indenting at all.
You want no linefeeds, no indenting at all, this is your formatter! Suitable use cases may be to generate a pure HTML file, which will only read by browsers for pure optimization.